Copy all Issues and PRs for a user or organization
Source:R/backup_github_info.R
backup_github_info.RdTo provide a backup on github failure, this function streamlines downloading all github Issues and Pull Requests of all repositories of a focal user or organization into local jsons.
Usage
backup_github_info(name, save_location, entity_type = c("user", "org"))Value
Invisibly returns a tibble with:
$repo_name= name of repository$full_name= full github name ({user or org}/{repo name})$issues_path= filepath to the json of issues$pulls_path= filepath to the json of pulls$issues_status,$pulls_status= Did the backup work? "success" or "error"$issues_error_msg,$pulls_error_msg= error messages on attempting to back up (NA if there was no error.)