Build manual (and optionally vignettes) for individual repository
Source:R/compile_package_manuals.R
build_package_manual.RdFor an R package stored on Github, compile a pdf reference manual and optionally build any vignettes. Requires LaTeX to run. Under the hood, downloads temporary copy of github repo, compiles document(s), then deletes repository.
Arguments
- repo_address
Github repository "full name" of form
{user}/{repository}, as in"FRAMverse/framrsquared". Also accepts full url (e.g.,"https://github.com/FRAMverse/framrsquared/) Character atomic.- output_path
Filepath for a directory into which to save manuals. Character atomic.
- build_vignettes
Attempt to build vignettes for any package that has them? Logical, defaults to
FALSE.- verbose
Print progress statements? Logical, defaults to
TRUE.