Returns github issues as a list. Github issues themselves are structured as jsons.
Arguments
- repo_address
Github identifier in the form of {name}/{repository}, as in "FRAMverse/codeInspectr". Can also be in the form of full URL (e.g. "https://github.com/FRAMverse/framrsquared/"). Character string, defaults to NULL. If not provided, users must instead provide the same information in
entity_nameandrepo_name.- entity_name
Only needed if
repo_addressis not provided. Name of a github user or organization repository, e.g., "FRAMverse". Character atomic, defaults toNULL.- repo_name
Only needed if
repo_addressis not provided. Name of individual repository, e.g., "codeInspectr". Character atomic, defaults toNULL.